Skip to contents

Generate a list of series from a dataframe

Usage

ec_series(df, ...)

Arguments

df

A dataframe that can be referenced by all other arguments

...

data dimensions and series attributes

Unnamed arguments are used as data dimensions in the order provided. Named arguments should be valid series attributes.